@@ -1,6 +1,6 @@
 package Bundle::Personal::lze;
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 1;
 
@@ -12,55 +12,87 @@ Bundle::Personal::lze
 
 =head1 SYNOPSIS
 
-	perl -MCPAN -e 'install Bundle::Personal::lze'
+perl -MCPAN -e 'install Bundle::Personal::lze'
 
 =head1 CONTENTS
 
+
+Apache::DB
+
+Apache2::Status
+
+Authen::Captcha
+
 CGI
 
 CGI::QuickForm
 
-Mail::Sendmail
+Complete::Bash
 
-HTML::Parser
+Complete::Util
 
-MD5
+CPAN::Uploader
 
-HTML::Menu::TreeView
+Module::CPANTS::Analyse
+
+Module::CPANTS::Kwalitee
 
 DBI
 
+Frontier::RPC2
+
 GD
 
-XML::Twig
-
-XML::RSS
-
-LWP::UserAgent
-
-Syntax::Highlight::Perl
-
-Test::More
-
-Pod::Usage
-
 Getopt::Long
 
+HTML::Menu::TreeView
+
+HTML::Parser
+
+IO::Prompter
+
+LWP::UserAgent
+
+MD5
+
+Mail::Sendmail
+
 Module::Build
 
+MySQL::Admin
+
+Pod::Usage
+
+Search::Tools::UTF8
+
+Syntax::Highlight::Engine::Kate
+
+Syntax::Highlight::Perl
+
+Term::ANSIColor
+
+Term::Bash::Completion::Generator
+
+Test::More
+
 Test::Pod
 
 Test::Pod::Coverage
 
-HTML::Menu::TreeView
+URI
+
+XML::RSS
+
+XML::Twig
+
+XML::XSLT
+
 
-MySQL::Admin
 
 =head1 DESCRIPTION
 
 Personal Modulebundle
 
-
 =head1 SEE ALSO
 
 http://lindnerei.de
